@@ -16,14 +16,20 @@ def get_end_activities(df):
 		ea_dict[el] = int(ea_dict[el])
 	return ea_dict
 
-def filter_start_activities(df, list_act):
+def filter_start_activities(df, list_act, retain=True):
 	first_df = get_first_df(df)
 	first_df = first_df[first_df[Constants.TARGET_ACTIVITY].isin(list_act)]
 	cases = first_df[Constants.TARGET_CASE_IDX].unique()
-	return df[df[Constants.TARGET_CASE_IDX].isin(cases)]
+	if retain:
+		return df[df[Constants.TARGET_CASE_IDX].isin(cases)]
+	else:
+		return df[~df[Constants.TARGET_CASE_IDX].isin(cases)]
 
-def filter_end_activities(df, list_act):
+def filter_end_activities(df, list_act, retain=True):
 	last_df = get_last_df(df)
 	last_df = last_df[last_df[Constants.TARGET_ACTIVITY].isin(list_act)]
 	cases = last_df[Constants.TARGET_CASE_IDX].unique()
-	return df[df[Constants.TARGET_CASE_IDX].isin(cases)]
+	if retain:
+		return df[df[Constants.TARGET_CASE_IDX].isin(cases)]
+	else:
+		return df[~df[Constants.TARGET_CASE_IDX].isin(cases)]
